==> kubernetes-model-apiextensions-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrArrayBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class JSONSchemaPropsOrArrayBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<?> fluent;
    Boolean validationEnabled;

    public JSONSchemaPropsOrArrayBuilder() {
        this(true);
    }

    public JSONSchemaPropsOrArrayBuilder(Boolean validationEnabled) {
        this(new JSONSchemaPropsOrArray(), validationEnabled);
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<?> fluent) {
        this(fluent, true);
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new JSONSchemaPropsOrArray(), validationEnabled);
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray instance) {
        this(fluent, instance, true);
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withJSONSchemas(instance.getJSONSchemas()); 
        fluent.withSchema(instance.getSchema()); 
        this.validationEnabled = validationEnabled; 
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray instance) {
        this(instance,true);
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withJSONSchemas(instance.getJSONSchemas()); 
        this.withSchema(instance.getSchema()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray build() {
        JSONSchemaPropsOrArray buildable = new JSONSchemaPropsOrArray(fluent.getJSONSchemas(),fluent.getSchema());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        JSONSchemaPropsOrArrayBuilder that = (JSONSchemaPropsOrArrayBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-apiextensions-5.4.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/JSONSchemaPropsOrArrayBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class JSONSchemaPropsOrArrayBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayBuilder> {

    io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public JSONSchemaPropsOrArrayBuilder() {
        this(true);
    }

    public JSONSchemaPropsOrArrayBuilder(java.lang.Boolean validationEnabled) {
        this(new JSONSchemaPropsOrArray(), validationEnabled);
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<?> fluent) {
        this(fluent, true);
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new JSONSchemaPropsOrArray(), validationEnabled);
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray instance) {
        this(fluent, instance, true);
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArrayFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withJSONSchemas(instance.getJSONSchemas()); 
        fluent.withSchema(instance.getSchema()); 
        this.validationEnabled = validationEnabled; 
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray instance) {
        this(instance,true);
    }

    public JSONSchemaPropsOrArrayBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withJSONSchemas(instance.getJSONSchemas()); 
        this.withSchema(instance.getSchema()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.JSONSchemaPropsOrArray build() {
        JSONSchemaPropsOrArray buildable = new JSONSchemaPropsOrArray(fluent.getJSONSchemas(),fluent.getSchema());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        JSONSchemaPropsOrArrayBuilder that = (JSONSchemaPropsOrArrayBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
